==> audiochain-1.1.5-src.tgz: org/audiochain/devices/level/PeakProgrammeMeterComponent.java <==
/**
   AudioChain Copyright (C) 2012-2013 Florian Paul (www.audiochain.org)
   
   This program is free software; you can redistribute it and/or modify it under the terms of the 
   GNU General Public License as published by the Free Software Foundation; either version 3 of the 
   License, or (at your option) any later version.
   
   This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without 
   even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General 
   Public License for more details.
   
   You should have received a copy of the GNU General Public License along with this program; 
   if not, see <http://www.gnu.org/licenses/>. 
 */
package org.audiochain.devices.level;

import static org.audiochain.ui.LightEmittingDiode.*;

import java.awt.Color;
import java.awt.Font;
import java.awt.event.KeyAdapter;
import java.awt.event.KeyEvent;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import java.io.IOException;

import javax.sound.sampled.AudioFormat;
import javax.sound.sampled.AudioSystem;
import javax.sound.sampled.Mixer;
import javax.swing.BorderFactory;
import javax.swing.JFrame;
import javax.swing.UIManager;

import org.audiochain.io.AudioDataReader;
import org.audiochain.io.AudioIOException;
import org.audiochain.io.FrameObserver;
import org.audiochain.io.LineAudioDataReader;
import org.audiochain.io.LineFrameObserver;
import org.audiochain.ui.LightEmittingDiodeArray;
import org.audiochain.ui.PeakProgrammeMeterEvent;
import org.audiochain.ui.PeakProgrammeMeterVisualizer;
import org.audiochain.ui.gui.LightEmittingDiodeMatrixComponent;


public class PeakProgrammeMeterComponent extends LightEmittingDiodeMatrixComponent implements PeakProgrammeMeterVisualizer {
	private static final long serialVersionUID = 1L;

	private static final int[] colors = {
		GREEN, GREEN, GREEN, 
		GREEN, GREEN, GREEN, 
		GREEN, GREEN, GREEN, 
		GREEN, GREEN, GREEN, 
		GREEN, GREEN, GREEN, 
		GREEN, GREEN, GREEN, 
		GREEN, GREEN, GREEN, 
		GREEN, GREEN, GREEN, 
		GREEN, GREEN, GREEN, 
		GREEN, GREEN, GREEN, 
		GREEN, GREEN, GREEN, 
		GREEN, GREEN, GREEN, 
		GREEN, GREEN, GREEN, 
		GREEN, GREEN, YELLOW, 
		YELLOW, YELLOW, YELLOW, 
		YELLOW, YELLOW, YELLOW, 
		YELLOW, YELLOW, YELLOW, 
		YELLOW, YELLOW, YELLOW, 
		YELLOW, YELLOW, YELLOW, 
		RED, RED, RED
	};
	private final LightEmittingDiodeArray leftLightEmittingDiodeArray;
	private final LightEmittingDiodeArray rightLightEmittingDiodeArray;
	
	public PeakProgrammeMeterComponent(int ledWidth, int ledHeight) {
		super(2, colors, ledWidth, ledHeight, 1);
		leftLightEmittingDiodeArray = getLightEmittingDiodeMatrix().getLightEmittingDiodeArray(0);
		rightLightEmittingDiodeArray = getLightEmittingDiodeMatrix().getLightEmittingDiodeArray(1);
	}

	@Override
	public void updatePeakProgrammeMeter(PeakProgrammeMeterEvent event) {
		leftLightEmittingDiodeArray.setLedValue(event.getLeftValue());
		leftLightEmittingDiodeArray.setLedSingleValue(event.getLeftPeakValue());
		rightLightEmittingDiodeArray.setLedValue(event.getRightValue());
		rightLightEmittingDiodeArray.setLedSingleValue(event.getRightPeakValue());
		repaint();
	}

	public static void main(String[] args) throws IOException, AudioIOException {
		if (args.length == 0) {
			System.out.println("usage: " + PeakProgrammeMeterComponent.class.getSimpleName() + " <mixer index>");
			return;
		}

		int sampleRate = 44100;
		int sampleSizeInBits = 16;
		int channels = 2;
		int frameSizeInBytes = sampleSizeInBits * channels / 8;
		int frameRate = sampleRate;
		AudioFormat format = new AudioFormat(AudioFormat.Encoding.PCM_SIGNED, sampleRate, sampleSizeInBits, channels, frameSizeInBytes, frameRate, true);
		Mixer mixer = AudioSystem.getMixer(AudioSystem.getMixerInfo()[Integer.parseInt(args[0])]);
		showPpm(format, mixer).setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
	}

	public static JFrame showPpm(AudioFormat format, Mixer mixer) throws IOException, AudioIOException {
		Font font = new Font("Sans", Font.PLAIN, 10);
		UIManager.put("Label.font", font);
		UIManager.put("Label.foreground", Color.WHITE);

		int ledWidth = 20;
		int ledHeight = 5;
		PeakProgrammeMeterComponent ppm = new PeakProgrammeMeterComponent(ledWidth, ledHeight);
		ppm.setBorder(BorderFactory.createEtchedBorder());

		LineAudioDataReader line = new LineAudioDataReader(format, mixer);
		FrameObserver fo = new LineFrameObserver(line.getLine());
		SamplePeakProgrammeMeterAudioDevice device = new SamplePeakProgrammeMeterAudioDevice();
		device.addPeakProgrammeMeterVisualizer(ppm);
		final AudioDataReader reader = device.createAudioDataReaderChainLink(line, format.getFrameRate(), format.getSampleSizeInBits(), fo);

		final JFrame frame = new JFrame();
		frame.setUndecorated(true);
		frame.getContentPane().setBackground(Color.DARK_GRAY);
		frame.getContentPane().add(ppm);
		frame.setBounds(775, 120, ledWidth * 2 + 3, (ledHeight + 1) * colors.length + 1);
		frame.setVisible(true);
		frame.addWindowListener(new WindowAdapter() {
			@Override
			public void windowClosing(WindowEvent event) {
				reader.stop();
				try {
					reader.close();
				} catch (IOException e) {
					e.printStackTrace();
				}
			}
		});
		frame.addKeyListener(new KeyAdapter() {
			@Override
			public void keyTyped(KeyEvent event) {
				frame.setVisible(false);
				reader.stop();
				try {
					reader.close();
				} catch (IOException e) {
					e.printStackTrace();
				}
			}
		});

		int[] data = new int[1024];
		while (reader.read(data) != -1) {

		}
		return frame;
	}
}

==> audiochain-1.1.6-src.tgz: org/audiochain/devices/level/PeakProgrammeMeterComponent.java <==
/**
   AudioChain Copyright (C) 2012-2013 Florian Paul (www.audiochain.org)
   
   This program is free software; you can redistribute it and/or modify it under the terms of the 
   GNU General Public License as published by the Free Software Foundation; either version 3 of the 
   License, or (at your option) any later version.
   
   This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without 
   even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General 
   Public License for more details.
   
   You should have received a copy of the GNU General Public License along with this program; 
   if not, see <http://www.gnu.org/licenses/>. 
 */
package org.audiochain.devices.level;

import static org.audiochain.ui.LightEmittingDiode.GREEN;
import static org.audiochain.ui.LightEmittingDiode.RED;
import static org.audiochain.ui.LightEmittingDiode.YELLOW;

import java.awt.Color;
import java.awt.Font;
import java.awt.event.KeyAdapter;
import java.awt.event.KeyEvent;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import java.io.IOException;

import javax.sound.sampled.AudioFormat;
import javax.sound.sampled.AudioSystem;
import javax.sound.sampled.Mixer;
import javax.swing.BorderFactory;
import javax.swing.JFrame;
import javax.swing.UIManager;

import org.audiochain.io.AudioDataReader;
import org.audiochain.io.AudioIOException;
import org.audiochain.io.FrameObserver;
import org.audiochain.io.LineAudioDataReader;
import org.audiochain.io.LineFrameObserver;
import org.audiochain.ui.LightEmittingDiodeArray;
import org.audiochain.ui.PeakProgrammeMeterEvent;
import org.audiochain.ui.PeakProgrammeMeterVisualizer;
import org.audiochain.ui.gui.LightEmittingDiodeMatrixComponent;


public class PeakProgrammeMeterComponent extends LightEmittingDiodeMatrixComponent implements PeakProgrammeMeterVisualizer {
	private static final long serialVersionUID = 1L;

	private static final int[] colors = {
		GREEN, GREEN, GREEN, 
		GREEN, GREEN, GREEN, 
		GREEN, GREEN, GREEN, 
		GREEN, GREEN, GREEN, 
		GREEN, GREEN, GREEN, 
		GREEN, GREEN, GREEN, 
		GREEN, GREEN, GREEN, 
		GREEN, GREEN, GREEN, 
		GREEN, GREEN, GREEN, 
		GREEN, GREEN, GREEN, 
		GREEN, GREEN, GREEN, 
		GREEN, GREEN, GREEN, 
		GREEN, GREEN, GREEN, 
		GREEN, GREEN, YELLOW, 
		YELLOW, YELLOW, YELLOW, 
		YELLOW, YELLOW, YELLOW, 
		YELLOW, YELLOW, YELLOW, 
		YELLOW, YELLOW, YELLOW, 
		YELLOW, YELLOW, YELLOW, 
		RED, RED, RED
	};
	private final LightEmittingDiodeArray leftLightEmittingDiodeArray;
	private final LightEmittingDiodeArray rightLightEmittingDiodeArray;
	
	public PeakProgrammeMeterComponent(int ledWidth, int ledHeight) {
		super(2, colors, ledWidth, ledHeight, 1);
		leftLightEmittingDiodeArray = getLightEmittingDiodeMatrix().getLightEmittingDiodeArray(0);
		rightLightEmittingDiodeArray = getLightEmittingDiodeMatrix().getLightEmittingDiodeArray(1);
	}

	@Override
	public void updatePeakProgrammeMeter(PeakProgrammeMeterEvent event) {
		leftLightEmittingDiodeArray.setLedValue(event.getLeftValue());
		leftLightEmittingDiodeArray.setLedSingleValue(event.getLeftPeakValue());
		rightLightEmittingDiodeArray.setLedValue(event.getRightValue());
		rightLightEmittingDiodeArray.setLedSingleValue(event.getRightPeakValue());
		repaint();
	}

	public static void main(String[] args) throws IOException, AudioIOException {
		if (args.length == 0) {
			System.out.println("usage: " + PeakProgrammeMeterComponent.class.getSimpleName() + " <mixer index>");
			return;
		}

		int sampleRate = 44100;
		int sampleSizeInBits = 16;
		int channels = 2;
		int frameSizeInBytes = sampleSizeInBits * channels / 8;
		int frameRate = sampleRate;
		AudioFormat format = new AudioFormat(AudioFormat.Encoding.PCM_SIGNED, sampleRate, sampleSizeInBits, channels, frameSizeInBytes, frameRate, true);
		Mixer mixer = AudioSystem.getMixer(AudioSystem.getMixerInfo()[Integer.parseInt(args[0])]);
		showPpm(format, mixer).setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
	}

	public static JFrame showPpm(AudioFormat format, Mixer mixer) throws IOException, AudioIOException {
		Font font = new Font("Sans", Font.PLAIN, 10);
		UIManager.put("Label.font", font);
		UIManager.put("Label.foreground", Color.WHITE);

		int ledWidth = 20;
		int ledHeight = 5;
		PeakProgrammeMeterComponent ppm = new PeakProgrammeMeterComponent(ledWidth, ledHeight);
		ppm.setBorder(BorderFactory.createEtchedBorder());

		LineAudioDataReader line = new LineAudioDataReader(format, mixer);
		FrameObserver fo = new LineFrameObserver(line.getLine());
		SamplePeakProgrammeMeterAudioDevice device = new SamplePeakProgrammeMeterAudioDevice();
		device.addPeakProgrammeMeterVisualizer(ppm);
		final AudioDataReader reader = device.createAudioDataReaderChainLink(line, format.getFrameRate(), format.getSampleSizeInBits(), fo);

		final JFrame frame = new JFrame();
		frame.setUndecorated(true);
		frame.getContentPane().setBackground(Color.DARK_GRAY);
		frame.getContentPane().add(ppm);
		frame.setBounds(775, 120, ledWidth * 2 + 3, (ledHeight + 1) * colors.length + 1);
		frame.setVisible(true);
		frame.addWindowListener(new WindowAdapter() {
			@Override
			public void windowClosing(WindowEvent event) {
				reader.stop();
				try {
					reader.close();
				} catch (IOException e) {
					e.printStackTrace();
				}
			}
		});
		frame.addKeyListener(new KeyAdapter() {
			@Override
			public void keyTyped(KeyEvent event) {
				frame.setVisible(false);
				reader.stop();
				try {
					reader.close();
				} catch (IOException e) {
					e.printStackTrace();
				}
			}
		});

		int[] data = new int[1024];
		while (reader.read(data) != -1) {

		}
		return frame;
	}
}
